diff --git a/Octokit/Clients/StatisticsClient.cs b/Octokit/Clients/StatisticsClient.cs
index 382864ae..94068b3c 100644
--- a/Octokit/Clients/StatisticsClient.cs
+++ b/Octokit/Clients/StatisticsClient.cs
@@ -15,14 +15,18 @@ namespace Octokit
}
///
/// Returns a list of for the given repo
///
/// The owner of the repository
/// The name of the repository
/// A list of
public Task> Contributors(string owner, string repositoryName)
{
- throw new NotImplementedException();
+ Ensure.ArgumentNotNullOrEmptyString(owner, "owner");
+ Ensure.ArgumentNotNullOrEmptyString(repositoryName, "repositoryName");
+
+ var endpoint = "/repos/{0}/{1}/stats/contributors".FormatUri(owner,repositoryName);
+ return ApiConnection.Get>(endpoint);
}
}
}
@@ -15,14 +15,18 @@ namespace Octokit
}
///
- /// Returns a list of for the given repo
+ /// Returns a list of for the given repository
///
/// The owner of the repository
\ No newline at end of file